@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyBrowser.cpp 6844 2007-01-23 17:41:33Z chpe $
+ *  $Id: EphyBrowser.cpp 6986 2007-04-09 12:07:42Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -750,6 +750,7 @@ nsresult EphyBrowser::SetPrintPreviewMode (PRBool previewMode)
 							   ephy_embed_shell_get_page_setup (shell),
 							   NULL,
 							   nsCString(),
+                                                           nsIPrintSettings::kFramesAsIs,
 							   PR_FALSE,
 							   settings);
 
