@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp 6644 2006-10-15 14:05:40Z wbolster $
+ * $Id: MozDownload.cpp 6895 2007-02-08 16:55:11Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -444,6 +444,20 @@ MozDownload::OnProgressChange64 (nsIWebProgress *aWebProgress,
 	return NS_OK;
 }
 
+#ifdef HAVE_GECKO_1_9
+/* boolean onRefreshAttempted (in nsIWebProgress aWebProgress, in nsIURI aRefreshURI, in long aDelay, in boolean aSameURI); */
+NS_IMETHODIMP
+MozDownload::OnRefreshAttempted(nsIWebProgress *aWebProgress,
+                                nsIURI *aUri,
+                                PRInt32 aDelay,
+                                PRBool aSameUri,
+                                PRBool *allowRefresh)
+{
+        *allowRefresh = PR_TRUE;
+        return NS_OK;
+}
+#endif
+
 NS_IMETHODIMP
 MozDownload::OnLocationChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest, nsIURI *location)
 {
